@@ -113,7 +113,6 @@ class TiiaClient(AbstractClient):
         >
         - 可前往 [图像搜索](https://cloud.tencent.com/document/product/1589) 产品文档中查看更多产品信息。
 
-
         :param request: Request instance for CreateImage.
         :type request: :class:`tencentcloud.tiia.v20190529.models.CreateImageRequest`
         :rtype: :class:`tencentcloud.tiia.v20190529.models.CreateImageResponse`
@@ -247,11 +246,11 @@ class TiiaClient(AbstractClient):
 
         |序号 | 标签名称 | 标签值 |
         | :-----|  :----------   |:-----------------  |
-        | 1 | 厨师服识别<div style="width: 70pt"> |无厨师服、有厨师服、被优选过滤|
-        | 2 | 厨师服识别（酒店版）<div style="width: 70pt"> |无厨师服、有厨师服、被优选过滤|
-        | 3 | 厨师帽识别<div style="width: 70pt"> |无厨师帽、有厨师帽、被优选过滤	|
-        | 4 | 赤膊识别<div style="width: 70pt"> |非赤膊、赤膊、被优选过滤|
-        | 5 | 口罩识别<div style="width: 70pt"> |无口罩、有口罩、口罩不确定、被优选过滤	|
+        | 1 | 厨师服识别<div style="width: 70pt"/> |无厨师服、有厨师服、被优选过滤|
+        | 2 | 厨师服识别（酒店版）<div style="width: 70pt"/> |无厨师服、有厨师服、被优选过滤|
+        | 3 | 厨师帽识别<div style="width: 70pt"/> |无厨师帽、有厨师帽、被优选过滤	|
+        | 4 | 赤膊识别<div style="width: 70pt"/> |非赤膊、赤膊、被优选过滤|
+        | 5 | 口罩识别<div style="width: 70pt"/> |无口罩、有口罩、口罩不确定、被优选过滤	|
 
         :param request: Request instance for DetectChefDress.
         :type request: :class:`tencentcloud.tiia.v20190529.models.DetectChefDressRequest`
@@ -505,15 +504,15 @@ class TiiaClient(AbstractClient):
 
         |序号 | 标签名称 | 标签值 |
         | :-----|  :----------   |:-----------------  |
-        | 1 | 安全帽识别<div style="width: 70pt"> |无安全帽、有安全帽、被优选过滤|
-        | 2 | 玩手机识别<div style="width: 70pt"> |没有电话、打电话、玩手机、被优选过滤|
-        | 3 | 抽烟识别<div style="width: 70pt"> |没有抽烟、抽烟、被优选过滤	|
-        | 4 | 口罩识别<div style="width: 70pt"> |无口罩、有口罩、口罩不确定、被优选过滤|
-        | 5 | 工地安全带识别<div style="width: 70pt"> |无工地安全带、工地安全带、被优选过滤	|
-        | 6 | 手套识别<div style="width: 70pt"> |无手套、有手套、手套不确定、被优选过滤	|
-        | 7 | 工服识别<div style="width: 70pt"> |无工服、有工服、被优选过滤|
-        | 8 | 护目镜识别<div style="width: 70pt"> |无护目镜、有护目镜、被优选过滤|
-        | 9 | 反光衣识别<div style="width: 70pt"> |无反光衣、有反光衣、被优选过滤|
+        | 1 | 安全帽识别<div style="width: 70pt"/> |无安全帽、有安全帽、被优选过滤|
+        | 2 | 玩手机识别<div style="width: 70pt"/> |没有电话、打电话、玩手机、被优选过滤|
+        | 3 | 抽烟识别<div style="width: 70pt"/> |没有抽烟、抽烟、被优选过滤	|
+        | 4 | 口罩识别<div style="width: 70pt"/> |无口罩、有口罩、口罩不确定、被优选过滤|
+        | 5 | 工地安全带识别<div style="width: 70pt"/> |无工地安全带、工地安全带、被优选过滤	|
+        | 6 | 手套识别<div style="width: 70pt"/> |无手套、有手套、手套不确定、被优选过滤	|
+        | 7 | 工服识别<div style="width: 70pt"/> |无工服、有工服、被优选过滤|
+        | 8 | 护目镜识别<div style="width: 70pt"/> |无护目镜、有护目镜、被优选过滤|
+        | 9 | 反光衣识别<div style="width: 70pt"/> |无反光衣、有反光衣、被优选过滤|
 
         :param request: Request instance for DetectSecurity.
         :type request: :class:`tencentcloud.tiia.v20190529.models.DetectSecurityRequest`
@@ -622,7 +621,6 @@ class TiiaClient(AbstractClient):
         >
         - 可前往 [图像搜索](https://cloud.tencent.com/document/product/1589) 产品文档中查看更多产品信息。
 
-
         :param request: Request instance for SearchImage.
         :type request: :class:`tencentcloud.tiia.v20190529.models.SearchImageRequest`
         :rtype: :class:`tencentcloud.tiia.v20190529.models.SearchImageResponse`
@@ -649,7 +647,6 @@ class TiiaClient(AbstractClient):
         >
         - 可前往 [图像搜索](https://cloud.tencent.com/document/product/1589) 产品文档中查看更多产品信息。
 
-
         :param request: Request instance for UpdateImage.
         :type request: :class:`tencentcloud.tiia.v20190529.models.UpdateImageRequest`
         :rtype: :class:`tencentcloud.tiia.v20190529.models.UpdateImageResponse`
